pub struct Artifact {Show 13 fields
pub id: String,
pub path: String,
pub content_hash: String,
pub preview_path: Option<String>,
pub model: String,
pub model_id: String,
pub runtime: String,
pub capability: Capability,
pub params: JsonValue,
pub created_at: i64,
pub duration_ms: i64,
pub job_id: String,
pub session_id: Option<String>,
}Expand description
A stored generated output: where its bytes live, a content hash, provenance (model/runtime/capability/params), timing, and ownership (job, session).
Fields
id: Stringpath: StringThe output file path, relative to the store root.
content_hash: StringSHA-256 (hex) of the output bytes.
preview_path: Option<String>model: StringThe model’s display name.
model_id: StringThe model’s registry id.
runtime: Stringcapability: Capabilityparams: JsonValuecreated_at: i64Creation time, epoch milliseconds.
duration_ms: i64job_id: Stringsession_id: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Artifact
impl<'de> Deserialize<'de> for Artifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Artifact