pub const fn bit_mask_u32(x: usize) -> u32Expand description
Returns a 32-bit bitmask of x low bits set, matching C++’s BIT_MASK32(x) from <bits.h>.
pub const fn bit_mask_u32(x: usize) -> u32Returns a 32-bit bitmask of x low bits set, matching C++’s BIT_MASK32(x) from <bits.h>.