pub const fn bit_mask_u64(x: usize) -> u64Expand description
Returns a bitmask of x low bits set, matching C++’s BIT_MASK(x) from <bits.h>.
pub const fn bit_mask_u64(x: usize) -> u64Returns a bitmask of x low bits set, matching C++’s BIT_MASK(x) from <bits.h>.