pub struct ToolSpec {
pub name: String,
pub description: String,
pub parameters: JsonValue,
}Expand description
A tool a model may be offered: a name, a description, and a JSON-Schema parameter object.
Fields
name: Stringdescription: Stringparameters: JsonValueImplementations
Sourceimpl ToolSpec
impl ToolSpec
Sourcepub fn new(
name: impl Into<String>,
description: impl Into<String>,
parameters: JsonValue,
) -> Self
pub fn new( name: impl Into<String>, description: impl Into<String>, parameters: JsonValue, ) -> Self
A tool spec.
Sourcepub fn payload_value(&self) -> JsonValue
pub fn payload_value(&self) -> JsonValue
The {name, description, parameters} payload form.
Sourcepub fn from_payload(value: &JsonValue) -> Option<Self>
pub fn from_payload(value: &JsonValue) -> Option<Self>
Parse a spec from its payload form, or None if it has no name.
Sourcepub fn from_payload_array(value: Option<&JsonValue>) -> Vec<Self>
pub fn from_payload_array(value: Option<&JsonValue>) -> Vec<Self>
Parse an array of specs, dropping any that don’t parse.