pub struct PolicyData(/* private fields */);Expand description
Policy data.
Rust abstraction for the C struct cpufreq_policy_data.
Invariants
A PolicyData instance always corresponds to a valid C struct cpufreq_policy_data.
The callers must ensure that the struct cpufreq_policy_data is valid for access and remains
valid for the lifetime of the returned reference.
Implementations
Sourceimpl PolicyData
impl PolicyData
Sourcepub unsafe fn from_raw_mut<'a>(ptr: *mut cpufreq_policy_data) -> &'a mut Self
pub unsafe fn from_raw_mut<'a>(ptr: *mut cpufreq_policy_data) -> &'a mut Self
Creates a mutable reference to an existing struct cpufreq_policy_data pointer.
Safety
The caller must ensure that ptr is valid for writing and remains valid for the lifetime
of the returned reference.
Sourcepub fn as_raw(&self) -> *mut cpufreq_policy_data
pub fn as_raw(&self) -> *mut cpufreq_policy_data
Returns a raw pointer to the underlying C cpufreq_policy_data.
Sourcepub fn generic_verify(&self) -> Result
pub fn generic_verify(&self) -> Result
Wrapper for cpufreq_generic_frequency_table_verify.