pub struct DuplicateGroup {
pub names: Vec<String>,
pub paths: Vec<String>,
pub wasted_bytes: i64,
}Expand description
A set of files found to be duplicates of one another.
Fields
names: Vec<String>The display names of the duplicate models, sorted.
paths: Vec<String>The paths of the duplicate files, sorted.
wasted_bytes: i64The bytes that could be reclaimed by keeping just one copy.