pub trait Handler: Sync + 'static {
// Required method
fn handle(&self, device: &Device<Bound>) -> IrqReturn;
}Expand description
Callbacks for an IRQ handler.
Required Methods
Sourcefn handle(&self, device: &Device<Bound>) -> IrqReturn
fn handle(&self, device: &Device<Bound>) -> IrqReturn
The hard IRQ handler.
This is executed in interrupt context, hence all corresponding limitations do apply.
All work that does not necessarily need to be executed from
interrupt context, should be deferred to a threaded handler.
See also ThreadedRegistration.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".