Struct kernel::reg::memory_mapped::Register
source · #[repr(transparent)]pub struct Register<S: RegisterSpec>(VolatileCell<S::Bits>);Expand description
A memory-mapped register which owns its value.
Register is #[repr(transparent)] so that it can be placed in a #[repr(C)] struct
matching a peripheral’s memory layout. Casting a value to a pointer to the register block allows
simple and safe access to a peripheral’s entire register set.
Tuple Fields
0: VolatileCell<S::Bits>Implementations
sourceimpl<S: RegisterSpec + RegisterReadable> Register<S>
impl<S: RegisterSpec + RegisterReadable> Register<S>
sourcepub fn read<R>(&self, reader: impl FnOnce(&RegisterReader<S>) -> R) -> R
pub fn read<R>(&self, reader: impl FnOnce(&RegisterReader<S>) -> R) -> R
Reads the current value of the register, providing access through an instance of
RegisterReader.
The register’s value is only read once: when read is called. This is the value accessed
through bit or field getters on RegisterReader inside the reader closure.
The return value of the reader closure is returned by read.
sourceimpl<S: RegisterSpec + RegisterWritable> Register<S>
impl<S: RegisterSpec + RegisterWritable> Register<S>
sourcepub unsafe fn write_zero(&self, writer: impl FnOnce(&mut RegisterWriter<S>))
pub unsafe fn write_zero(&self, writer: impl FnOnce(&mut RegisterWriter<S>))
Writes a value built by an instance of RegisterWriter, initialised to zero, to the
register.
The register’s value is only written once: when the writer closure returns. The value
written is the value built through bit or field setters on RegisterWriter inside the
writer closure.
Safety
Setting bits or fields to zero may result in undefined behaviour, as zero is not guaranteed to be a supported value. Refer to the register’s definition to determine valid values.
sourceimpl<S: RegisterSpec + RegisterInitial> Register<S>
impl<S: RegisterSpec + RegisterInitial> Register<S>
sourcepub fn write_initial(&self, writer: impl FnOnce(&mut RegisterWriter<S>))
pub fn write_initial(&self, writer: impl FnOnce(&mut RegisterWriter<S>))
Writes a value built by an instance of RegisterWriter, initialised to the register’s
initial value (provided by RegisterInitial), to the register.
The register’s value is only written once: when the writer closure returns. The value
written is the value built through bit or field setters on RegisterWriter inside the
writer closure.