Struct kernel::reg::RegisterWriter

source ·
pub struct RegisterWriter<S: RegisterSpec> {
    bits: S::Bits,
}
Provides write access to the fields of a register.

Fields

bits: S::Bits

Implementations

source

impl RegisterWriter<DAIF>

source

pub fn d(&mut self, d: bool)

source

pub fn a(&mut self, a: bool)

source

pub fn i(&mut self, i: bool)

source

pub fn f(&mut self, f: bool)

source

impl RegisterWriter<GICD_CTLR>

source

pub fn enable(&mut self, enable: bool)

source

impl RegisterWriter<GICD_ISENABLER>

source

pub fn set_enable(&mut self, m: usize)

source

impl RegisterWriter<GICC_CTLR>

source

pub fn enable(&mut self, enable: bool)

source

impl RegisterWriter<GICC_PMR>

source

pub fn priority(&mut self, priority: u8)

source

impl RegisterWriter<GICC_EOIR>

source

pub fn entire_iar(&mut self, iar: u32)

source

impl RegisterWriter<NZCV>

source

pub fn n(&mut self, n: bool)

source

pub fn z(&mut self, z: bool)

source

pub fn c(&mut self, c: bool)

source

pub fn v(&mut self, v: bool)

source

impl RegisterWriter<UARTDR>

source

pub fn data(&mut self, data: u8)

source

impl<S: RegisterSpec> RegisterWriter<S>

source

fn zero() -> Self

source

impl<S: RegisterSpec + RegisterInitial> RegisterWriter<S>

source

fn initial() -> Self

source

impl<S: RegisterSpec> RegisterWriter<S>

source

pub unsafe fn bits(&mut self, bits: S::Bits)

Sets the raw value.

Safety

Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.

source

pub unsafe fn bit(&mut self, offset: usize, bit: bool)

Sets the value of the bit at offset offset.

Safety

Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.

source

pub unsafe fn field(&mut self, range: RangeInclusive<usize>, field: S::Bits)

Sets the value of a contiguous bit field with its LSB at the offset range.start() and MSB at the offset range.end().

  bits: | ... | |x|x|x| ... |x|x| | ... | | | | |
                 ^             ^               ^
offset:          range.end()   range.start()   0
Safety

Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.