Struct kernel::reg::system::Register

source ·
pub struct Register<S: SystemRegisterSpec>(PhantomData<S>);
An AArch64 system register accessed with the mrs and msr assembly instructions.

Tuple Fields

0: PhantomData<S>

Implementations

source

impl<S: SystemRegisterSpec> Register<S>

source

pub fn new() -> Self

source

impl<S: SystemRegisterSpec + RegisterReadable> Register<S>

source

pub fn read<R>(&self, reader: impl FnOnce(&RegisterReader<S>) -> R) -> R

Reads the current value of the register, providing access through an instance of RegisterReader.

The register’s value is only read once: when read is called. This is the value accessed through bit or field getters on RegisterReader inside the reader closure.

The return value of the reader closure is returned by read.

source

impl<S: SystemRegisterSpec + RegisterWritable> Register<S>

source

pub unsafe fn write_zero(&self, writer: impl FnOnce(&mut RegisterWriter<S>))

Writes a value built by an instance of RegisterWriter, initialised to zero, to the register.

The register’s value is only written once: when the writer closure returns. The value written is the value built through bit or field setters on RegisterWriter inside the writer closure.

Safety

Setting bits or fields to zero may result in undefined behaviour, as zero is not guaranteed to be a supported value. Refer to the register’s definition to determine valid values.

source

impl<S: SystemRegisterSpec + RegisterWritable + RegisterInitial> Register<S>

source

pub fn write_initial(&self, writer: impl FnOnce(&mut RegisterWriter<S>))

Writes a value built by an instance of RegisterWriter, initialised to the register’s initial value (provided by RegisterInitial), to the register.

The register’s value is only written once: when the writer closure returns. The value written is the value built through bit or field setters on RegisterWriter inside the writer closure.