pub fn ollama_chat_profile() -> GgufArchitectureProfileExpand description
The default profile for an Ollama chat model with no more specific match.
pub fn ollama_chat_profile() -> GgufArchitectureProfileThe default profile for an Ollama chat model with no more specific match.