pub fn preempt_clear_timeslice_extension()Expand description
Clears an expiring timeslice extension on the current thread’s preemption state.
pub fn preempt_clear_timeslice_extension()Clears an expiring timeslice extension on the current thread’s preemption state.