pub fn sleep_relative(duration: DurationMono) -> Result<(), Status>Expand description
Sleeps the current thread for the specified relative duration.
pub fn sleep_relative(duration: DurationMono) -> Result<(), Status>Sleeps the current thread for the specified relative duration.