AutoExpiringPreemptDisabler

Struct AutoExpiringPreemptDisabler 

pub struct AutoExpiringPreemptDisabler { /* private fields */ }
RAII guard that sets a timeslice extension for its scope.

This guard is !Send and !Sync because timeslice extensions modify CPU- and thread-local state.

Implementations

Source

impl AutoExpiringPreemptDisabler

pub fn new(duration: DurationMono) -> Self

Creates a new guard and attempts to set a timeslice extension for duration.