AutoPreemptDisabler

Struct AutoPreemptDisabler 

pub struct AutoPreemptDisabler { /* private fields */ }
RAII guard that disables preemption for its scope.

This guard is !Send and !Sync because preemption state is CPU- and thread-local.

Implementations

Source

impl AutoPreemptDisabler

pub fn new() -> Self

Creates a new guard and immediately disables preemption.

pub fn new_deferred() -> Self

Creates a new guard without immediately disabling preemption.

pub fn disable(&mut self)

Disables preemption if not already disabled by this guard instance.

pub fn enable(&mut self)

Re-enables preemption if previously disabled by this guard instance.

pub fn is_disabled(&self) -> bool

Returns whether preemption is currently disabled by this guard instance.