ThreadPtr

Struct ThreadPtr 

pub struct ThreadPtr(/* private fields */);
Type-safe wrapper around a raw pointer to a Zircon kernel Thread.

Implementations

Source

impl ThreadPtr

pub const unsafe fn from_raw(ptr: *mut c_void) -> Option<Self>

Creates a ThreadPtr from a raw pointer.

Safety

The caller must ensure that ptr is a valid pointer to a live kernel thread.

pub const fn as_raw(self) -> *mut c_void

Returns the raw pointer.

pub unsafe fn resume(self)

Resumes execution of the thread.

Safety

The caller must ensure the thread has not been joined or destroyed.

pub unsafe fn join(self, deadline: zx_instant_mono_t) -> Result<i32, Status>

Joins the thread, waiting for it to exit.

Returns the thread’s return code on success.

Safety

The caller must ensure that the thread has not been joined yet.

pub unsafe fn kill(self)

Kills the thread.

Safety

The caller must ensure the thread is still valid.

pub unsafe fn is_blocked(self) -> bool

Checks if the thread is currently blocked.

Safety

The caller must ensure that the thread pointer is still valid and the underlying thread has not been destroyed or joined.

pub unsafe fn current() -> Self

Returns a ThreadPtr representing the currently executing thread.

Safety

The caller must ensure that this function is called after multi-threading has been initialized (i.e. after LK_INIT_LEVEL_THREADING).

pub unsafe fn fxt_ref(self) -> FxtRef

Returns the thread’s process and thread KOIDs.

Safety

The caller must ensure that the thread pointer is still valid and the underlying thread has not been destroyed.