HrTimerExpires

Trait HrTimerExpires 

pub trait HrTimerExpires {
    // Required method
    fn as_nanos(&self) -> i64;
}
Time representations that can be used as expiration values in HrTimer.

Required Methods

fn as_nanos(&self) -> i64

Converts the expiration time into a nanosecond representation.

This value corresponds to a raw ktime_t value, suitable for passing to kernel timer functions. The interpretation (absolute vs relative) depends on the associated HrTimerMode in use.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors