ScopedHrTimerPointer

Trait ScopedHrTimerPointer 

pub unsafe trait ScopedHrTimerPointer {
    type TimerMode: HrTimerMode;

    // Required method
    fn start_scoped<T, F>(
        self,
        expires: <Self::TimerMode as HrTimerMode>::Expires,
        f: F,
    ) -> T
       where F: FnOnce() -> T;
}
A trait for stack allocated timers.

Safety

Implementers must ensure that start_scoped does not return until the timer is dead and the timer handler is not running.

Required Associated Types

type TimerMode: HrTimerMode

The operational mode associated with this timer.

This defines how the expiration value is interpreted.

Required Methods

fn start_scoped<T, F>( self, expires: <Self::TimerMode as HrTimerMode>::Expires, f: F, ) -> T
where F: FnOnce() -> T,

Start the timer to run after expires time units and immediately after call f. When f returns, the timer is cancelled.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors