pub struct Timer { /* private fields */ }Implementations
Sourceimpl Timer
impl Timer
pub fn init(clock_id: u32) -> impl PinInit<Self, Infallible>
Sourcepub unsafe fn set_deadline(
self: Pin<&mut Self>,
deadline: &Deadline,
callback: Callback,
arg: *mut c_void,
)
pub unsafe fn set_deadline( self: Pin<&mut Self>, deadline: &Deadline, callback: Callback, arg: *mut c_void, )
Schedules the timer to fire at the specified deadline.
Safety
The caller must ensure that:
callbackis a valid FFI callback that does not cause undefined behavior when executed.argis either a valid pointer or a null pointer, and is safe to pass tocallback.
Sourcepub unsafe fn set_oneshot(
self: Pin<&mut Self>,
deadline: i64,
callback: Callback,
arg: *mut c_void,
)
pub unsafe fn set_oneshot( self: Pin<&mut Self>, deadline: i64, callback: Callback, arg: *mut c_void, )
Schedules the timer to fire once at the specified deadline (in nanoseconds).
Safety
Same as Self::set_deadline.
pub fn cancel(self: Pin<&mut Self>) -> bool