pub extern "C" fn test_timer_oneshot() -> boolExpand description
Verifies that a scheduled oneshot timer fires and executes its callback.
pub extern "C" fn test_timer_oneshot() -> boolVerifies that a scheduled oneshot timer fires and executes its callback.