Struct kernel::tt::page::PhysicalAddress
source · #[repr(transparent)]pub struct PhysicalAddress<T> {
addr: usize,
phantom: PhantomData<T>,
}Expand description
A physical address, with an in-memory representation equivalent to a regular pointer to a value
of type T. Uses the kernel’s 1:1 physical memory mapping for accesses via Self::ptr() and
Self::ptr_mut().
As with a regular pointer, this type confers no guarantees of validity or alignment.
The physical address may:
- be null
- be unmapped in the kernel’s 1:1 physical memory mapping (an issue unique to physical addresses)
- point to uninitialised memory
- alias an existing immutable or mutable reference
- be misaligned for a value of type
T - lack any other guarantee as described in
core::ptror the nomicon
Fields
addr: usizephantom: PhantomData<T>Implementations
sourceimpl<T> PhysicalAddress<T>
impl<T> PhysicalAddress<T>
sourceconst PHYS_BASE: usize = 18_446_462_598_732_840_960usize
const PHYS_BASE: usize = 18_446_462_598_732_840_960usize
The base of the kernel’s 1:1 physical memory mapping.
pub fn from_addr(addr: usize) -> Self
sourcepub fn ptr(self) -> *const T
pub fn ptr(self) -> *const T
Returns a regular pointer using the kernel’s 1:1 physical memory mapping.
sourcepub fn ptr_mut(self) -> *mut T
pub fn ptr_mut(self) -> *mut T
Returns a regular, mutable pointer using the kernel’s 1:1 physical memory mapping.
sourcepub fn cast<U>(self) -> PhysicalAddress<U>
pub fn cast<U>(self) -> PhysicalAddress<U>
Casts to a physical address of another type.