RawDelayedWorkItem

Trait RawDelayedWorkItem 

pub unsafe trait RawDelayedWorkItem<const ID: u64>: RawWorkItem<ID> { }
A raw delayed work item.

Safety

If the __enqueue method in the RawWorkItem implementation calls the closure, then the provided pointer must point at the work field of a valid delayed_work, and the guarantees that __enqueue provides about accessing the work_struct must also apply to the rest of the delayed_work struct.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, const ID: u64> RawDelayedWorkItem<ID> for Pin<KBox<T>>
where T: WorkItem<ID, Pointer = Self> + HasDelayedWork<T, ID>,

Implementors

Source

impl<T, const ID: u64> RawDelayedWorkItem<ID> for ARef<T>
where T: WorkItem<ID, Pointer = Self> + HasDelayedWork<T, ID> + AlwaysRefCounted,

Source

impl<T, const ID: u64> RawDelayedWorkItem<ID> for Arc<T>
where T: WorkItem<ID, Pointer = Self> + HasDelayedWork<T, ID>,