Struct kernel::reg::RegisterWriter
source · pub struct RegisterWriter<S: RegisterSpec> {
bits: S::Bits,
}Expand description
Provides write access to the fields of a register.
Fields
bits: S::BitsImplementations
sourceimpl RegisterWriter<DAIF>
impl RegisterWriter<DAIF>
sourceimpl RegisterWriter<GICD_ISENABLER>
impl RegisterWriter<GICD_ISENABLER>
pub fn set_enable(&mut self, m: usize)
sourceimpl RegisterWriter<GICC_EOIR>
impl RegisterWriter<GICC_EOIR>
pub fn entire_iar(&mut self, iar: u32)
sourceimpl RegisterWriter<NZCV>
impl RegisterWriter<NZCV>
sourceimpl<S: RegisterSpec> RegisterWriter<S>
impl<S: RegisterSpec> RegisterWriter<S>
sourceimpl<S: RegisterSpec + RegisterInitial> RegisterWriter<S>
impl<S: RegisterSpec + RegisterInitial> RegisterWriter<S>
sourceimpl<S: RegisterSpec> RegisterWriter<S>
impl<S: RegisterSpec> RegisterWriter<S>
sourcepub unsafe fn bits(&mut self, bits: S::Bits)
pub unsafe fn bits(&mut self, bits: S::Bits)
Sets the raw value.
Safety
Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.
sourcepub unsafe fn bit(&mut self, offset: usize, bit: bool)
pub unsafe fn bit(&mut self, offset: usize, bit: bool)
Sets the value of the bit at offset offset.
Safety
Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.
sourcepub unsafe fn field(&mut self, range: RangeInclusive<usize>, field: S::Bits)
pub unsafe fn field(&mut self, range: RangeInclusive<usize>, field: S::Bits)
Sets the value of a contiguous bit field with its LSB at the offset range.start() and MSB
at the offset range.end().
bits: | ... | |x|x|x| ... |x|x| | ... | | | | |
^ ^ ^
offset: range.end() range.start() 0
Safety
Setting an unsupported value may result in undefined behaviour. Refer to the register’s definition to determine valid values.