RelaxedAtomic

Struct RelaxedAtomic 

pub struct RelaxedAtomic<T> { /* private fields */ }
Wrapper around atomic types that assumes Ordering::Relaxed for all operations to simplify pure relaxed use cases.

Implementations

Source

impl RelaxedAtomic<AtomicI8>

pub const fn new(value: i8) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> i8

Loads the value with relaxed ordering.

pub fn store(&self, desired: i8)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: i8) -> i8

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: i8) -> i8

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: i8) -> i8

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: i8) -> i8

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicI16>

pub const fn new(value: i16) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> i16

Loads the value with relaxed ordering.

pub fn store(&self, desired: i16)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: i16) -> i16

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: i16) -> i16

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: i16) -> i16

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: i16) -> i16

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicI32>

pub const fn new(value: i32) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> i32

Loads the value with relaxed ordering.

pub fn store(&self, desired: i32)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: i32) -> i32

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: i32) -> i32

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: i32) -> i32

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: i32) -> i32

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicI64>

pub const fn new(value: i64) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> i64

Loads the value with relaxed ordering.

pub fn store(&self, desired: i64)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: i64) -> i64

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: i64) -> i64

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: i64) -> i64

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: i64) -> i64

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicIsize>

pub const fn new(value: isize) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> isize

Loads the value with relaxed ordering.

pub fn store(&self, desired: isize)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: isize) -> isize

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: isize) -> isize

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: isize) -> isize

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: isize) -> isize

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicU8>

pub const fn new(value: u8) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> u8

Loads the value with relaxed ordering.

pub fn store(&self, desired: u8)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: u8) -> u8

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: u8) -> u8

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: u8) -> u8

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: u8) -> u8

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicU16>

pub const fn new(value: u16) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> u16

Loads the value with relaxed ordering.

pub fn store(&self, desired: u16)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: u16) -> u16

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: u16) -> u16

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: u16) -> u16

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: u16) -> u16

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicU32>

pub const fn new(value: u32) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> u32

Loads the value with relaxed ordering.

pub fn store(&self, desired: u32)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: u32) -> u32

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: u32) -> u32

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: u32) -> u32

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: u32) -> u32

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicU64>

pub const fn new(value: u64) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> u64

Loads the value with relaxed ordering.

pub fn store(&self, desired: u64)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: u64) -> u64

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: u64) -> u64

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: u64) -> u64

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: u64) -> u64

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.

Source

impl RelaxedAtomic<AtomicUsize>

pub const fn new(value: usize) -> Self

Creates a new RelaxedAtomic.

pub fn load(&self) -> usize

Loads the value with relaxed ordering.

pub fn store(&self, desired: usize)

Stores the value with relaxed ordering.

pub fn fetch_add(&self, value: usize) -> usize

Adds to the current value, returning the previous value, with relaxed ordering.

pub fn fetch_sub(&self, value: usize) -> usize

Subtracts from the current value, returning the previous value, with relaxed ordering.

pub fn fetch_and(&self, value: usize) -> usize

Bitwise “and” with the current value, returning the previous value, with relaxed ordering.

pub fn fetch_or(&self, value: usize) -> usize

Bitwise “or” with the current value, returning the previous value, with relaxed ordering.