Trait kernel::sync::atomic::AtomicImpl
source · pub trait AtomicImpl: Sized + Send + Copy + Sealed {
type Delta;
}Expand description
A marker trait for types that implement atomic operations with C side primitives.
This trait is sealed, and only types that map directly to the C side atomics or can be implemented with lower-level C primitives are allowed to implement this:
i8andi16are implemented with lower-level C primitives.i32map toatomic_ti64map toatomic64_t
Required Associated Types
Object Safety
This trait is not object safe.