pub struct AutoExpiringPreemptDisabler { /* private fields */ }Expand description
RAII guard that sets a timeslice extension for its scope.
This guard is !Send and !Sync because timeslice extensions modify CPU- and thread-local
state.
Implementations
Sourceimpl AutoExpiringPreemptDisabler
impl AutoExpiringPreemptDisabler
Sourcepub fn new(duration: DurationMono) -> Self
pub fn new(duration: DurationMono) -> Self
Creates a new guard and attempts to set a timeslice extension for duration.